@@ -6,10 +6,10 @@ class HttpException(Exception):
 
 
 class UnauthenticatedException(HttpException):
-    def __init__(self, content='Unauthenticated', status_code: int = 401, headers={}):
+    def __init__(self, content='Unauthenticated', status_code: int = 401):
         super(UnauthenticatedException, self).__init__(content, status_code)
 
 
 class UnauthorizedException(HttpException):
-    def __init__(self, content='Unauthorized', status_code: int = 403, headers={}):
+    def __init__(self, content='Unauthorized', status_code: int = 403):
         super(UnauthorizedException, self).__init__(content, status_code)
